window.Gleam.initSearch([{"doc":"jotkey","title":"jotkey","content":"# jotkey\n\n[![Package Version](https://img.shields.io/hexpm/v/jotkey)](https://hex.pm/packages/jotkey)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/jotkey/)\n\nTiny library for &quot;translating&quot; djot syntax to lustre elements. Can convert to other renderers\n\n&gt; [!TIP]\n&gt; This is a fork from https://hexdocs.pm/lustre_ssg/lustre/ssg/djot.html. If using lustre ssg \n&gt; I&#39;ll recommend to not use this library if context aware systems are not needed.\n\n```sh\ngleam add jotkey\n```\n```gleam\nimport gleam/io\nimport lustre/element/html\nimport jotkey\nimport jot\n\npub fn main() {\n    let jot_body = &quot;\n# A heading that\n# takes up\n# three lines\n\n{.important .large}\nA paragraph, finally\n\n[My link text](http://example.com)\n    &quot;\n\n    io.debug(\n        html.body([], \n            jot_body \n            |&gt; jot.parse\n            |&gt; jotkey.render(jotkey.default_renderer(), [])\n    )\n\n}\n```\n\n## Advanced usage\n\n\n```gleam\nimport gleam/io\nimport lustre/element/html\nimport jotkey\nimport jot\n\npub fn main() {\n    let jot_body = &quot;\n\n{slug=Esoteric-programming-language title=\\&quot;Esoteric programming languages\\&quot;}\nview:wikipedia\n\n{slug=Esoteric-programming-language}\nview:wikipedia\n\n{slug=Not-Found}\nview:wikipedia\n\n    &quot;\n\n    io.debug(\n        html.body([], \n            jot_body \n            |&gt; jot.parse\n            |&gt; jotkey.render(context_aware_lustre_renderer(), [\n                WikipediaDocument(&quot;Esoteric-programming-language&quot;),\n                WikipediaDocument(&quot;Shakespeare-Programming-Language&quot;),\n            ])\n    )\n}\n\n\ntype TestContextItem {\n  WikipediaDocument(slug: String)\n}\n\nfn context_aware_lustre_renderer() {\n  let to_attributes = fn(attrs) {\n    use attrs, key, val &lt;- dict.fold(attrs, [])\n    [attribute(key, val), ..attrs]\n  }\n\n  Renderer(\n    codeblock: fn(attrs, lang, code, _context) {\n      let lang = option.unwrap(lang, &quot;text&quot;)\n      html.pre(to_attributes(attrs), [\n        html.code([attribute(&quot;data-lang&quot;, lang)], [element.text(code)]),\n      ])\n    },\n    emphasis: fn(content, _context) { html.em([], content) },\n    heading: fn(attrs, level, content, _context) {\n      case level {\n        1 -&gt; html.h1(to_attributes(attrs), content)\n        2 -&gt; html.h2(to_attributes(attrs), content)\n        3 -&gt; html.h3(to_attributes(attrs), content)\n        4 -&gt; html.h4(to_attributes(attrs), content)\n        5 -&gt; html.h5(to_attributes(attrs), content)\n        6 -&gt; html.h6(to_attributes(attrs), content)\n        _ -&gt; html.p(to_attributes(attrs), content)\n      }\n    },\n    link: fn(destination, references, content, _context) {\n      case destination {\n        jot.Reference(ref) -&gt;\n          case dict.get(references, ref) {\n            Ok(url) -&gt; html.a([attribute.href(url)], content)\n            Error(_) -&gt; html.a([attribute.href(ref)], content)\n          }\n        jot.Url(url) -&gt; html.a([attribute(&quot;href&quot;, url)], content)\n      }\n    },\n    paragraph: fn(attrs, content, context) {\n      case content {\n        [vdom.Text(&quot;view:wikipedia&quot;)] -&gt; {\n          let wiki_slug = result.unwrap(dict.get(attrs, &quot;slug&quot;), &quot;none&quot;)\n          case\n            list.find(context, fn(context_item) {\n              case context_item {\n                WikipediaDocument(slug) if slug == wiki_slug -&gt; True\n                _ -&gt; False\n              }\n            })\n          {\n            Ok(_) -&gt;\n              html.div([], [\n                html.text(result.unwrap(dict.get(attrs, &quot;title&quot;), &quot;No title&quot;)),\n              ])\n            _ -&gt; element.none()\n          }\n        }\n        _ -&gt; html.p(to_attributes(attrs), content)\n      }\n    },\n    strong: fn(content, _context) { html.strong([], content) },\n    text: fn(text, _context) { element.text(text) },\n    code: fn(content, _context) { html.code([], [element.text(content)]) },\n    image: fn(destination, alt, _context) {\n      case destination {\n        jot.Reference(ref) -&gt; html.img([attribute.src(ref), attribute.alt(alt)])\n        jot.Url(url) -&gt; html.img([attribute.src(url), attribute.alt(alt)])\n      }\n    },\n    linebreak: fn(_context) { html.br([]) },\n  )\n}\n\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/jotkey&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"jotkey","title":"Renderer","content":"pub type Renderer(view, context) {\n  Renderer(\n    codeblock: fn(\n      Dict(String, String),\n      Option(String),\n      String,\n      context,\n    ) -&gt;\n      view,\n    emphasis: fn(List(view), context) -&gt; view,\n    heading: fn(Dict(String, String), Int, List(view), context) -&gt;\n      view,\n    link: fn(\n      jot.Destination,\n      Dict(String, String),\n      List(view),\n      context,\n    ) -&gt;\n      view,\n    paragraph: fn(Dict(String, String), List(view), context) -&gt;\n      view,\n    strong: fn(List(view), context) -&gt; view,\n    text: fn(String, context) -&gt; view,\n    code: fn(String, context) -&gt; view,\n    image: fn(jot.Destination, String, context) -&gt; view,\n    linebreak: fn(context) -&gt; view,\n  )\n}\n A renderer for a djot document, knows how to turn each block or inline element\n into some custom view. That view could be anything, but it&#39;s typically a\n Lustre element.\n\n Some ideas for other renderers include:\n\n - A renderer that turns a djot document into a JSON object\n - A renderer that generates a table of contents\n - A renderer that generates Nakai elements instead of Lustre ones\n\n\n This renderer is compatible with **v1.0.2** of the [jot](https://hexdocs.pm/jot/jot.html)\n package.\n \n For more advanced usage check examples implementing context aware renderers\n\nRenderer(\n  codeblock: fn(\n    Dict(String, String),\n    Option(String),\n    String,\n    context,\n  ) -&gt;\n    view,\n  emphasis: fn(List(view), context) -&gt; view,\n  heading: fn(Dict(String, String), Int, List(view), context) -&gt;\n    view,\n  link: fn(\n    jot.Destination,\n    Dict(String, String),\n    List(view),\n    context,\n  ) -&gt;\n    view,\n  paragraph: fn(Dict(String, String), List(view), context) -&gt;\n    view,\n  strong: fn(List(view), context) -&gt; view,\n  text: fn(String, context) -&gt; view,\n  code: fn(String, context) -&gt; view,\n  image: fn(jot.Destination, String, context) -&gt; view,\n  linebreak: fn(context) -&gt; view,\n)\n\n\nSynonyms:\njotkey.Renderer\njotkey Renderer","url":"jotkey.html#Renderer"},{"doc":"jotkey","title":"default_renderer","content":"pub fn default_renderer() -&gt; Renderer(Element(a), b)\n The default renderer generates some sensible Lustre elements from a djot\n document. You can use this if you need a quick drop-in renderer for some\n markup in a Lustre project.\n\nSynonyms:\njotkey.default_renderer\njotkey default_renderer","url":"jotkey.html#default_renderer"},{"doc":"jotkey","title":"render","content":"pub fn render(\n  document: Document,\n  renderer: Renderer(a, b),\n  context: b,\n) -&gt; List(a)\n Render a djot document using the given renderer.\n\nSynonyms:\njotkey.render\njotkey render","url":"jotkey.html#render"},{"doc":"jotkey","title":"jotkey","content":"","url":"jotkey.html"}]);